@@ -1,7 +1,8 @@
 import numpy as np
+import pandas as pd
 import pytest
 
-from profiling.metrics import AUC, Accuracy
+from profiling.metrics import AUC, Accuracy, getloss
 
 
 @pytest.mark.parametrize(
@@ -48,3 +49,19 @@ def test_accuracy(pred, y, expected):
     loss = Accuracy()
     auc = loss.metric(pred, y)
     assert np.isclose(auc, expected)
+
+@pytest.mark.parametrize("name", ["Mae", "Rmse", "TrimmedRmse"])
+def test_index_invariance(name):
+    y_array = np.random.sample([10])
+    index = np.random.choice(100, len(y_array), replace=False)
+    y_series = pd.Series(y_array)
+    y_series.index = index
+
+    pred_array = np.random.sample([10])
+    pred_series = pd.Series(pred_array)
+
+    loss = getloss(name)
+    metric_series = loss.metric(pred_series, y_series)
+    metric_array = loss.metric(pred_array, y_array)
+
+    assert metric_series == metric_array
